@@ -2,7 +2,7 @@
 import { Platform } from 'react-native'
 const cheerio = require('react-native-cheerio')
 
-import {NativeModules} from 'react-native';
+import { NativeModules } from 'react-native';
 // module.exports = NativeModules.ToastExample;
 
 // import ToastExample from './ToastExample';
@@ -32,8 +32,9 @@ var DemoLibrary = {
       }).then(response => response.text())
         .then((response) => {
           //NativeModules.ToastExample.show('Awesome', NativeModules.ToastExample.SHORT);
-          NativeModules.DemoModuleExample.getPackageName((value)=>{
-            console.log('package ', value);
+          NativeModules.DemoModuleExample.getPackageName((package, version) => {
+            console.log('package ', package);
+            console.log('versio ', version);
           });
           const $ = cheerio.load(response)
           var version = $('<div/>').html(response).contents().find('div[itemprop=\"softwareVersion\"]').text().trim()
