@@ -1,5 +1,7 @@
 package com.reactlibrary.DemoLibrary;
 
+import com.facebook.react.BuildConfig;
+import com.facebook.react.bridge.Callback;
 import com.facebook.react.bridge.ReactApplicationContext;
 import com.facebook.react.bridge.ReactContextBaseJavaModule;
 import com.facebook.react.bridge.ReactMethod;
@@ -21,7 +23,6 @@ public class DemoModule extends ReactContextBaseJavaModule {
 
     @ReactMethod
     public void getPackageName(Callback successCallback) {
-successCallback.invoke(getReactApplicationContext().getPackageName());
-        
+        successCallback.invoke(getReactApplicationContext().getPackageName(), BuildConfig.VERSION_NAME);
     }
 }
